==> dojo-1.9.4.tgz: package/cldr/nls/sv/islamic.js <==
define(
//begin v1.x content
{
	"field-dayperiod": "fm/em",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"dayPeriods-format-wide-pm": "em",
	"field-minute": "minut",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-day-relative+-1": "i går",
	"field-weekday": "veckodag",
	"field-day-relative+-2": "i förrgår",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"field-era": "era",
	"dateFormatItem-Gy": "y G",
	"field-hour": "timme",
	"dayPeriods-format-wide-am": "fm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dateFormatItem-y": "y G",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"dateFormatItem-yyyy": "y G",
	"months-standAlone-abbr": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"dateFormatItem-Ed": "E d",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"eraAbbr": [
		"AH"
	],
	"field-day-relative+2": "i övermorgon",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormat-long": "d MMMM y G",
	"field-zone": "tidszon",
	"field-week-relative+-1": "förra veckan",
	"dateFormat-medium": "d MMM y G",
	"dayPeriods-format-narrow-pm": "e",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"field-year-relative+-1": "i fjol",
	"field-year": "år",
	"dayPeriods-format-narrow-am": "f",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabi’ al-awwal",
		"Rabi’ al-akhir",
		"Jumada-l-ula",
		"Jumada-l-akhira",
		"Rajab",
		"Sha’ban",
		"Ramadan",
		"Shawwal",
		"Dhu-l-ga’da",
		"Dhu-l-hijja"
	],
	"field-week": "vecka",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-yyyyMd": "G y-MM-dd",
	"dateFormatItem-yyyyMEd": "E, y-MM-dd G",
	"field-week-relative+0": "denna vecka",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+1": "nästa vecka",
	"months-format-abbr": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"field-month-relative+0": "denna månad",
	"field-month": "månad",
	"field-month-relative+1": "nästa månad",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-day": "dag",
	"dateFormatItem-MEd": "E d/M",
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"dayPeriods-format-abbr-pm": "EM",
	"dateFormat-short": "G y-MM-dd",
	"dateFormatItem-yyyyM": "G y-MM",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-Md": "d/M",
	"months-format-wide": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"dayPeriods-format-abbr-am": "FM",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-month-relative+-1": "förra månaden",
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	]
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/sv/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"field-second-relative+0": "nu",
	"field-weekday": "Veckodag",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-tue-relative+-1": "tisdag förra veckan",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-wed-relative+-1": "onsdag förra veckan",
	"months-format-wide": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"dayPeriods-format-wide-pm": "em",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-yyyyMEd": "E, y-MM-dd G",
	"field-thu-relative+-1": "torsdag förra veckan",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "FM",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabi’ al-awwal",
		"Rabi’ al-akhir",
		"Jumada-l-ula",
		"Jumada-l-akhira",
		"Rajab",
		"Sha’ban",
		"Ramadan",
		"Shawwal",
		"Dhu-l-ga’da",
		"Dhu-l-hijja"
	],
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"field-year": "År",
	"field-hour": "Timme",
	"months-format-abbr": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"field-day-relative+0": "i dag",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-day-relative+1": "i morgon",
	"field-thu-relative+1": "torsdag nästa vecka",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "i övermorgon",
	"months-standAlone-abbr": [
		"muharram",
		"safar",
		"rabi’ al-awwal",
		"rabi’ al-akhir",
		"jumada-l-ula",
		"jumada-l-akhira",
		"rajab",
		"sha’ban",
		"ramadan",
		"shawwal",
		"dhu-l-ga’da",
		"dhu-l-hijja"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AH"
	],
	"field-minute": "Minut",
	"field-dayperiod": "fm/em",
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"field-day-relative+-1": "i går",
	"dayPeriods-format-narrow-am": "f",
	"field-day-relative+-2": "i förrgår",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-day": "Dag",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-zone": "Tidszon",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "i fjol",
	"field-month-relative+-1": "förra månaden",
	"dayPeriods-format-abbr-pm": "EM",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "G y-MM-dd",
	"field-month": "Månad",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-relative+0": "tisdag denna vecka",
	"field-tue-relative+1": "tisdag nästa vecka",
	"dayPeriods-format-wide-am": "fm",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"dateFormat-short": "G y-MM-dd",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"dateFormatItem-Ed": "E d",
	"field-week": "Vecka",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "förra veckan",
	"dateFormatItem-yyyyM": "G y-MM",
	"field-year-relative+1": "nästa år",
	"dayPeriods-format-narrow-pm": "e",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "måndag förra veckan",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka"
}
//end v1.x content
);
